[![TekCloud Logo](https://raw.githubusercontent.com/tektronix/tekdrive-sdk-python/master/ext/tekcloud-logo.png)](https://tekcloud.com)

# TekDrive Python SDK
This is a Python SDK for interacting with the TekDrive API.

## Quick Links
#### SDK
- [PyPI](https://pypi.org/project/tekdrive/)
- [Documentation](https://tektronix.github.io/tekdrive-sdk-python/)
- [File a Bug/Request a Feature](https://github.com/tektronix/tekdrive-sdk-python/issues/new/choose)

#### Other
- [TekDrive API Documentation](https://docs.drive.tekcloud.com)
- [TekDrive Marketing Page](https://www.tek.com/software/tekdrive)


## Install
The SDK is available on PyPI:

```console
$ pip install tekdrive
```

This SDK officially supports Python 3.6+.
